[QGIS Commit] r9156 - trunk/qgis/src/plugins/wfs

svn_qgis at osgeo.org svn_qgis at osgeo.org
Sun Aug 24 16:17:57 EDT 2008


Author: jef
Date: 2008-08-24 16:17:57 -0400 (Sun, 24 Aug 2008)
New Revision: 9156

Modified:
   trunk/qgis/src/plugins/wfs/qgswfssourceselect.cpp
Log:
revert srs related wfs uri changes from r9108 (fixes #1246)

Modified: trunk/qgis/src/plugins/wfs/qgswfssourceselect.cpp
===================================================================
--- trunk/qgis/src/plugins/wfs/qgswfssourceselect.cpp	2008-08-24 18:20:25 UTC (rev 9155)
+++ trunk/qgis/src/plugins/wfs/qgswfssourceselect.cpp	2008-08-24 20:17:57 UTC (rev 9156)
@@ -184,22 +184,22 @@
       abstract = abstractList.at( 0 ).toElement().text();
     }
 
-    //DefaultCRS is always the first entry in the feature crs list
-    QDomNodeList defaultCRSList = featureTypeElem.elementsByTagNameNS( WFS_NAMESPACE, "DefaultCRS" );
+    //DefaultSRS is always the first entry in the feature srs list
+    QDomNodeList defaultCRSList = featureTypeElem.elementsByTagNameNS( WFS_NAMESPACE, "DefaultSRS" );
     if ( defaultCRSList.length() > 0 )
     {
       featureCRSList.push_back( defaultCRSList.at( 0 ).toElement().text() );
     }
 
-    //OtherCRS
-    QDomNodeList otherCRSList = featureTypeElem.elementsByTagNameNS( WFS_NAMESPACE, "OtherCRS" );
+    //OtherSRS
+    QDomNodeList otherCRSList = featureTypeElem.elementsByTagNameNS( WFS_NAMESPACE, "OtherSRS" );
     for ( unsigned int i = 0; i < otherCRSList.length(); ++i )
     {
       featureCRSList.push_back( otherCRSList.at( i ).toElement().text() );
     }
 
-    //Support <CRS> for compatibility with older versions
-    QDomNodeList srsList = featureTypeElem.elementsByTagNameNS( WFS_NAMESPACE, "CRS" );
+    //Support <SRS> for compatibility with older versions
+    QDomNodeList srsList = featureTypeElem.elementsByTagNameNS( WFS_NAMESPACE, "SRS" );
     for ( unsigned int i = 0; i < srsList.length(); ++i )
     {
       featureCRSList.push_back( srsList.at( i ).toElement().text() );
@@ -358,7 +358,7 @@
     long epsgNr = mProjectionSelector->getSelectedEpsg();
     if ( epsgNr != 0 )
     {
-      crsString = "&CRSNAME=EPSG:" + QString::number( epsgNr );
+      crsString = "&SRSNAME=EPSG:" + QString::number( epsgNr );
     }
   }
   //add a wfs layer to the map



More information about the QGIS-commit mailing list